@@ -5,7 +5,7 @@ use warnings;
 use base qw( Alien::Base );
 
 # ABSTRACT: Find or build bison, the parser generator
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 
 sub bin_dir
@@ -20,6 +20,14 @@ sub bin_dir
   return $class->SUPER::bin_dir;
 }
 
+
+sub alien_helper
+{
+  return {
+    bison => sub { 'bison' },
+  };
+}
+
 1;
 
 __END__
@@ -34,7 +42,7 @@ Alien::bison - Find or build bison, the parser generator
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -59,13 +67,21 @@ From Alien::Base Build.PL
 This package can be used by other CPAN modules that require bison,
 the GNU Parser generator based on YACC.
 
+=head1 HELPERS
+
+=head2 bison
+
+ %{bison}
+
+Returns the name of the bison command.  Usually just C<bison>.
+
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
